//SET DIRECTORY TO tables FOLDER HERE
use "..\replication_data.dta", clear

**SUMMARY MEASURES
egen rights_of_accused=rmean(public_trial0 provide_lawyer how_long_hold0)
label var rights_of_accused "Support Rights of Accused (0-1)"

egen gss_liberties=rmean(gss_speech gss_teach gss_book)
label var gss_liberties "GSS Tolerance Index (0-1)"


*TREATMENT interactions
gen trt_violenceXtrt_desc_terror=trt_violence*trt_desc_terror
gen trt_violenceXtrt_desc_violence=trt_violence*trt_desc_violence
label var trt_violenceXtrt_desc_terror "Explicit Call x Advocating Terrorism"
label var trt_violenceXtrt_desc_violence "Explicit Call x Advocating Violence"
gen trt_violenceXtrt_name_anglo=trt_violence*trt_name_anglo
gen trt_violenceXtrt_name_arab=trt_violence*trt_name_arab
label var trt_violenceXtrt_name_anglo "Explicit Call x Anglo Name"
label var trt_violenceXtrt_name_arab "Explicit Call x Arabic Name"

gen trt_name_arabXtrt_desc_terror=trt_name_arab*trt_desc_terror
gen trt_name_arabXtrt_desc_violence=trt_name_arab*trt_desc_violence
label var trt_name_arabXtrt_desc_terror "Arabic Name x Advocating Terrorism" 
label var trt_name_arabXtrt_desc_violence "Arabic Name x Advocating Violence" 
gen trt_name_angloXtrt_desc_terror=trt_name_anglo*trt_desc_terror
gen trt_name_angloXtrt_desc_violence=trt_name_anglo*trt_desc_violence
label var trt_name_angloXtrt_desc_terror "Anglo Name x Advocating Terrorism" 
label var trt_name_angloXtrt_desc_violence "Anglo Name x Advocating Violence" 


****ANALYSIS
*define sample
reg support_arrest encourage_speech public_trial provide_lawyer how_long_hold gss_speech gss_teach gss_book advocating_violence advocating_terrorism mot_* imminent_violence eventual_violence agree_w_speech other_plots worried trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence age pid female r_white r_black r_hispanic polinterest educ income, r
keep if e(sample)
outsum support_arrest encourage_speech public_trial provide_lawyer how_long_hold gss_speech gss_teach gss_book advocating_violence advocating_terrorism mot_* imminent_violence eventual_violence age pid female r_white r_black r_hispanic polinterest educ income using "A1_sumstats", replace bracket

****CENTER AT POPULATION MEANS (from ANES)
replace age=age-47.3746
replace r_white=r_white-.7092
replace female=female-.520697 
replace educ=educ-3.300163
replace income=income-7.436685
replace pid=pid-3.804482
replace polinterest=polinterest-1.795473 

foreach i in age r_white pid polinterest female educ income incomemis{
foreach t in trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence {
local label : variable label `i'
local label2 : variable label `t'
gen `i'X`t'=`i'*`t'
label var `i'X`t' "`label2' x `label'"
}
}

*balance test
gen conditions=trt_violence*10000+trt_name_arab*1 + trt_name_anglo*2 + trt_desc_terror*10 + trt_desc_viol*20
mlogit conditions age r_white pid polinterest female educ income incomemis


*Factor Analysis (TABLE A2)
*tolerate 
factor support_arrest encourage_speech public_trial0 provide_lawyer how_long_hold0 gss_speech gss_teach gss_book
rotate
predict permit_speech
label var permit_speech "Tolerance of Speech (M=0; SD=1)"

*intentions
factor advocating_violence advocating_terrorism  mot_*
rotate
predict bad_motives good_motives
label var bad_motives "Violent Intentions (M=0; SD=1)"
label var good_motives "Policy Change Intentions (M=0; SD=1)"

*consequence
foreach i in imminent_violence eventual_violence{
qui sum `i'
replace `i'=(`i'-r(mean))/r(sd)
}
egen consequences=rmean(imminent_violence eventual_violence)
label var consequences "Lead to Violence (M=0; SD=1)"
foreach i in permit_speech bad_motives good_motives consequences{
qui sum `i'
replace `i'=(`i'-r(mean))/r(sd)
}

*make MFX plot summary
foreach i in permit_speech bad_motives good_motives consequences{
reg `i' trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence, r
est store base
lincomest trt_violence 
est store viol_`i'
est restore base 
lincomest trt_name_arab-trt_name_anglo 
est store name_`i'
est restore base 
lincomest trt_desc_terror 
est store frame_`i'
est restore base 
test trt_name_arab==trt_name_anglo 
local name=r(p)
test trt_desc_terror==trt_desc_violence 
local desc=r(p)
test trt_desc_terror==trt_violence
local lab_comp=r(p)
test (trt_name_arab-trt_name_anglo)==trt_violence
local name_comp=r(p)
if "`i'"=="permit_speech"{
outreg using "T1_sum_measures", se bracket tdec(3) adec(3) replace label addstat("Name Treatments Equal? (p-value)",`name',"Framing Treatments Equal? (p-value)",`desc',"Name Treatment FX = Message FX? (p-value)",`name_comp',"Terrorism Label Treatment FX = Message FX? (p-value)",`lab_comp')
}
else{
outreg using "T1_sum_measures", se bracket tdec(3) adec(3) append label addstat("Name Treatments Equal? (p-value)",`name',"Framing Treatments Equal? (p-value)",`desc',"Name Treatment FX = Message FX? (p-value)",`name_comp',"Terrorism Label Treatment FX = Message FX? (p-value)",`lab_comp')
}

reg `i' trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence trt_violenceXtrt_desc_terror trt_violenceXtrt_desc_violence trt_name_arabXtrt_desc_terror trt_name_arabXtrt_desc_violence trt_name_angloXtrt_desc_terror trt_name_angloXtrt_desc_violence, r
test trt_violenceXtrt_desc_terror trt_violenceXtrt_desc_violence 
local violence=r(p)
test trt_name_arabXtrt_desc_terror trt_name_arabXtrt_desc_violence trt_name_angloXtrt_desc_terror trt_name_angloXtrt_desc_violence
local name=r(p)
if "`i'"=="permit_speech"{
outreg using "T2_sum_measures_X_models", se bracket tdec(3) adec(3) replace label addstat("Explicit call to violence moderate framing? (p-value)",`violence',"Name moderate framing? (p-value)",`name')
}
else{
outreg using "T2_sum_measures_X_models", se bracket tdec(3) adec(3) append label addstat("Explicit call to violence moderate framing? (p-value)",`violence',"Name moderate framing? (p-value)",`name')
}

reg `i' trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence age ageX* r_white r_whiteX* pid pidX* polinterest polinterestX* female femaleX* educ educX* income incomeX* incomemis incomemisX*, r
est store base
lincomest trt_violence 
est store viol_`i'_nat
est restore base 
lincomest trt_name_arab-trt_name_anglo 
est store name_`i'_nat
est restore base 
lincomest trt_desc_terror 
est store frame_`i'_nat
est restore base 
test trt_name_arab==trt_name_anglo 
local name=r(p)
test trt_desc_terror==trt_desc_violence 
local desc=r(p)
test trt_desc_terror==trt_violence
local lab_comp=r(p)
test (trt_name_arab-trt_name_anglo)==trt_violence
local name_comp=r(p)
outreg trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence using "T1_sum_measures", se bracket tdec(3) adec(3) append label addstat("Name Treatments Equal? (p-value)",`name',"Framing Treatments Equal? (p-value)",`desc',"Name Treatment FX = Message FX? (p-value)",`name_comp',"Terrorism Label Treatment FX = Message FX? (p-value)",`lab_comp')
}
coefplot (viol_permit_speech, rename((1) = "Tolerance of Speech") \viol_bad_motives, rename((1) = "Violent Intentions") \viol_good_motives, rename((1) = "Policy Change Intentions") \viol_consequences, rename((1) = "Lead to Violence") msymbol(O) connect(none) msize(medium) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Call to Violence)) (viol_permit_speech_nat, rename((1) = "Tolerance of Speech") \viol_bad_motives_nat, rename((1) = "Violent Intentions") \viol_good_motives_nat, rename((1) = "Policy Change Intentions") \viol_consequences_nat, rename((1) = "Lead to Violence") msymbol(Oh) connect(none) msize(medium) mcolor(black)  ciopts(lcolor(black) lpattern(solid) lwidth(thin) msize(vtiny)) label(Call to Violence)) (name_permit_speech, rename((1) = "Tolerance of Speech") \name_bad_motives, rename((1) = "Violent Intentions") \name_good_motives, rename((1) = "Policy Change Intentions") \name_consequences, rename((1) = "Lead to Violence") msymbol(T) connect(none) msize(medium) mcolor(gs7)  ciopts(lcolor(gs7) lwidth(thin) msize(vtiny)) label(Arabic - Anglo Name)) (name_permit_speech_nat, rename((1) = "Tolerance of Speech") \name_bad_motives_nat, rename((1) = "Violent Intentions") \name_good_motives_nat, rename((1) = "Policy Change Intentions") \name_consequences_nat, rename((1) = "Lead to Violence") msymbol(Th) connect(none) msize(medium) mcolor(gs7)  ciopts(lcolor(gs7) lwidth(thin) lpattern(solid) msize(vtiny)) label(Arabic - Anglo Name)) (frame_permit_speech, rename((1) = "Tolerance of Speech") \frame_bad_motives, rename((1) = "Violent Intentions") \frame_good_motives, rename((1) = "Policy Change Intentions") \frame_consequences, rename((1) = "Lead to Violence") msymbol(S) connect(none) msize(medium) mcolor(gs11)  ciopts(lcolor(gs11) lwidth(thin) msize(vtiny)) label(Advocating Terrorism)) (frame_permit_speech_nat, rename((1) = "Tolerance of Speech") \frame_bad_motives_nat, rename((1) = "Violent Intentions") \frame_good_motives_nat, rename((1) = "Policy Change Intentions") \frame_consequences_nat, rename((1) = "Lead to Violence") msymbol(Sh) connect(none) msize(medium) mcolor(gs11)  ciopts(lcolor(gs11) lpattern(solid) lwidth(thin) msize(vtiny)) label(Advocating Terrorism)), vertical legend(region(lcolor(white)) cols(1) ring(0) position(4) bmargin(large) size(medsmall) order(2 6 10)) level(95) coeflabels(,wrap(16)) ylab(-1 -.5 0 .5 1, nogrid) ytitle("Treatment Effect (standard deviations)") graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) yline(0, lc(black) lw(thin) ) xscale(lw(none)) 
graph save Graph "F1_fx_summary.gph", replace
graph export "F1_fx_summary.eps", as(eps) replace



**TOLERANCE**
foreach i in support_arrest encourage_speech rights_of_accused gss_liberties{
reg `i' trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence, r
test trt_name_arab==trt_name_anglo 
local name=r(p)
test trt_desc_terror==trt_desc_violence 
local desc=r(p)
test trt_desc_terror==trt_violence
local lab_comp=r(p)
test (trt_name_arab-trt_name_anglo)==trt_violence
local name_comp=r(p)
if "`i'"=="support_arrest"{
outreg using "A3_tolerate_speech", se bracket tdec(3) adec(3) replace label addstat("Name Treatments Equal? (p-value)",`name',"Framing Treatments Equal? (p-value)",`desc',"Name Treatment FX = Message FX? (p-value)",`name_comp',"Terrorism Label Treatment FX = Message FX? (p-value)",`lab_comp')
}
else{
outreg using "A3_tolerate_speech", se bracket tdec(3) adec(3) append label addstat("Name Treatments Equal? (p-value)",`name',"Framing Treatments Equal? (p-value)",`desc',"Name Treatment FX = Message FX? (p-value)",`name_comp',"Terrorism Label Treatment FX = Message FX? (p-value)",`lab_comp')
}
}
***INTENTIONS***
foreach i in imminent_violence eventual_violence {
reg `i' trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence, r
test trt_name_arab==trt_name_anglo 
local name=r(p)
test trt_desc_terror==trt_desc_violence 
local desc=r(p)
test trt_desc_terror==trt_violence
local lab_comp=r(p)
test (trt_name_arab-trt_name_anglo)==trt_violence
local name_comp=r(p)
if "`i'"=="imminent_violence"{
outreg using "A4_consequences", se bracket tdec(3) adec(3) replace label addstat("Name Treatments Equal? (p-value)",`name',"Framing Treatments Equal? (p-value)",`desc',"Name Treatment FX = Message FX? (p-value)",`name_comp',"Terrorism Label Treatment FX = Message FX? (p-value)",`lab_comp')
}
else{
outreg using "A4_consequences", se bracket tdec(3) adec(3) append label addstat("Name Treatments Equal? (p-value)",`name',"Framing Treatments Equal? (p-value)",`desc',"Name Treatment FX = Message FX? (p-value)",`name_comp',"Terrorism Label Treatment FX = Message FX? (p-value)",`lab_comp')
}
}

